==> nextcloud-12.0.3-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/encryption/l10n/is.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Vantar endurheimtulykilorð",
    "Please repeat the recovery key password" : "Endurtaktu endurheimtulykilorð",
    "Recovery key successfully enabled" : "Tókst að virkja endurheimtulykil",
    "Could not enable recovery key. Please check your recovery key password!" : "Tókst ekki að virkja endurheimtulykil. Athugaðu endurheimtulykilorðið þitt!",
    "Recovery key successfully disabled" : "Tókst að gera endurheimtulykil óvirkan",
    "Could not disable recovery key. Please check your recovery key password!" : "Tókst ekki að gera endurheimtulykil óvirkan. Athugaðu endurheimtulykilorðið þitt!",
    "Missing parameters" : "Vantar breytur",
    "Please provide the old recovery password" : "Settu inn gamla endurheimtulykilorðið",
    "Please provide a new recovery password" : "Settu inn nýja endurheimtulykilorðið",
    "Please repeat the new recovery password" : "Endurtaktu nýja endurheimtulykilorðið",
    "Password successfully changed." : "Lykilorðinu hefur verið breytt.",
    "Could not change the password. Maybe the old password was not correct." : "Tókst ekki að breyta lykilorðinu. Kannski var gamla lykilorðið ekki rétt.",
    "Recovery Key disabled" : "Endurheimtulykilorð óvirkt",
    "Recovery Key enabled" : "Endurheimtulykilorð virkt",
    "Could not enable the recovery key, please try again or contact your administrator" : "Gat ekki virkjað endurheimtulykilinn, reyndu aftur eða hafðu samband við kerfisstjóra",
    "Could not update the private key password." : "Tókst ekki að uppfæra lykilorð einkalykils.",
    "The old password was not correct, please try again." : "Gamla lykilorðið var ekki rétt, reyndu aftur.",
    "The current log-in password was not correct, please try again." : "Núgildandi innskráningarlykilorð var ekki rétt, reyndu aftur.",
    "Private key password successfully updated." : "Tókst að uppfæra lykilorð einkalykils.",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "Þú verður að yfirfæra dulritunarlyklana þína úr gömlu dulrituninni (ownCloud <= 8.0) yfir í þá nýju. Keyrðu 'occ encryption:migrate' eða hafðu samband við kerfisstjórann þinn",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "Dulritunarforritið er virkt en dulritunarlyklarnir þínir eru ekki tilbúnir til notkunar, skráðu þig út og svo aftur inn.",
    "Encryption app is enabled and ready" : "Dulritunarforrit er virkt og tilbúið til notkunar",
    "Bad Signature" : "Ógild undirritun",
    "Missing Signature" : "Vantar undirritun",
    "one-time password for server-side-encryption" : "eins-skiptis lykilorð fyrir dulritun á þjóni",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Get ekki afkóðað þessa skrá, hugsanlega er þetta deild skrá. Biddu eiganda skrárinnar að deila henni aftur til þín.",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Get ekki lesið þessa skrá, hugsanlega er þetta deild skrá. Biddu eiganda skrárinnar að deila henni aftur til þín.",
    "The share will expire on %s." : "Gildistími deilingar rennur út %s.",
    "Cheers!" : "Til hamingju!",
    "Default encryption module" : "Sjálfgefin dulritunareining",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "Dulritunarforritið er virkt en dulritunarlyklarnir þínir eru ekki tilbúnir til notkunar, skráðu þig út og svo aftur inn",
    "Encrypt the home storage" : "Dulrita heimamöppuna",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Ef þessi kostur er virkur verða allar skrár í aðalgeymslu dulritaðar, annars verða einungis skrár í ytri gagnageymslum dulritaðar",
    "Enable recovery key" : "Virkja endurheimtingarlykil",
    "Disable recovery key" : "Gera endurheimtingarlykil óvirkan",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "Endurheimtingarlykill er auka-dulritunarlykill sem er notaður til að dulrita skrár. Hann gefur möguleika á að endurheimta skrár ef notandi gleymir lykilorðinu sínu.",
    "Recovery key password" : "Endurheimtulykilorð",
    "Repeat recovery key password" : "Endurtaktu endurheimtulykilorðið",
    "Change recovery key password:" : "Breyta endurheimtulykilorði:",
    "Old recovery key password" : "Gamla endurheimtulykilorðið",
    "New recovery key password" : "Nýtt endurheimtulykilorð",
    "Repeat new recovery key password" : "Endurtaktu nýja endurheimtulykilorðið",
    "Change Password" : "Breyta lykilorði",
    "Basic encryption module" : "Grunn-dulritunareining",
    "Your private key password no longer matches your log-in password." : "Lykilorð einkalykilsins þíns samsvarar ekki lengur innskráningarlykilorðinu þínu.",
    "Set your old private key password to your current log-in password:" : "Settu eldra lykilorð einkalykilsins þíns á að vera það sama og núgildandi innskráningarlykilorðið þitt:",
    " If you don't remember your old password you can ask your administrator to recover your files." : " Ef þú manst ekki gamla lykilorðið þitt geturðu beðið kerfisstjórann þinn um að endurheimta skrárnar þínar.",
    "Old log-in password" : "Gamla lykilorðið",
    "Current log-in password" : "Núverandi lykilorð",
    "Update Private Key Password" : "Uppfæra lykilorð einkalykils:",
    "Enable password recovery:" : "Virkja endurheimtingu lykilorðs:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Ef þessi kostur er virkur gerir það þér kleift að endurheimta aðgang að skránum þínum ef þú tapar lykilorðinu",
    "Enabled" : "Virkt",
    "Disabled" : "Óvirkt",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "Dulritunarforritið er virkt en dulritunarlyklarnir þínir eru ekki tilbúnir til notkunar, skráðu þig út og svo aftur inn"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/encryption/l10n/is.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Vantar endurheimtulykilorð",
    "Please repeat the recovery key password" : "Endurtaktu endurheimtulykilorð",
    "Repeated recovery key password does not match the provided recovery key password" : "Endurtekna endurheimtulykilorðið samsvarar ekki uppgefnu endurheimtulykilorði",
    "Recovery key successfully enabled" : "Tókst að virkja endurheimtulykil",
    "Could not enable recovery key. Please check your recovery key password!" : "Tókst ekki að virkja endurheimtulykil. Athugaðu endurheimtulykilorðið þitt!",
    "Recovery key successfully disabled" : "Tókst að gera endurheimtulykil óvirkan",
    "Could not disable recovery key. Please check your recovery key password!" : "Tókst ekki að gera endurheimtulykil óvirkan. Athugaðu endurheimtulykilorðið þitt!",
    "Missing parameters" : "Vantar breytur",
    "Please provide the old recovery password" : "Settu inn gamla endurheimtulykilorðið",
    "Please provide a new recovery password" : "Settu inn nýja endurheimtulykilorðið",
    "Please repeat the new recovery password" : "Endurtaktu nýja endurheimtulykilorðið",
    "Password successfully changed." : "Lykilorðinu hefur verið breytt.",
    "Could not change the password. Maybe the old password was not correct." : "Tókst ekki að breyta lykilorðinu. Kannski var gamla lykilorðið ekki rétt.",
    "Recovery Key disabled" : "Endurheimtulykilorð óvirkt",
    "Recovery Key enabled" : "Endurheimtulykilorð virkt",
    "Could not enable the recovery key, please try again or contact your administrator" : "Gat ekki virkjað endurheimtulykilinn, reyndu aftur eða hafðu samband við kerfisstjóra",
    "Could not update the private key password." : "Tókst ekki að uppfæra lykilorð einkalykils.",
    "The old password was not correct, please try again." : "Gamla lykilorðið var ekki rétt, reyndu aftur.",
    "The current log-in password was not correct, please try again." : "Núgildandi innskráningarlykilorð var ekki rétt, reyndu aftur.",
    "Private key password successfully updated." : "Tókst að uppfæra lykilorð einkalykils.",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "Þú verður að yfirfæra dulritunarlyklana þína úr gömlu dulrituninni (ownCloud <= 8.0) yfir í þá nýju. Keyrðu 'occ encryption:migrate' eða hafðu samband við kerfisstjórann þinn",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Ógildur einkalykill fyrir dulritunarforrit. Uppfærðu einkalykilorðið í stillingunum þínum til að fá aftur aðgang að dulrituðu skránum þínum.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "Dulritunarforritið er virkt en dulritunarlyklarnir þínir eru ekki tilbúnir til notkunar, skráðu þig út og svo aftur inn.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "Virkjaðu dulritun á vefþjóninum í kerfisstjórnunarstillingunum svo hægt sé að nota dulritunareininguna.",
    "Encryption app is enabled and ready" : "Dulritunarforrit er virkt og tilbúið til notkunar",
    "Bad Signature" : "Ógild undirritun",
    "Missing Signature" : "Vantar undirritun",
    "one-time password for server-side-encryption" : "eins-skiptis lykilorð fyrir dulritun á þjóni",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Get ekki afkóðað þessa skrá, hugsanlega er þetta deild skrá. Biddu eiganda skrárinnar að deila henni aftur til þín.",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Get ekki lesið þessa skrá, hugsanlega er þetta deild skrá. Biddu eiganda skrárinnar að deila henni aftur til þín.",
    "Hey there,\n\nthe admin enabled server-side-encryption. Your files were encrypted using the password '%s'.\n\nPlease login to the web interface, go to the section 'basic encryption module' of your personal settings and update your encryption password by entering this password into the 'old log-in password' field and your current login-password.\n\n" : "Hæ,\n\nkerfisstjórinn virkjaði dulritun á vefþjóni. Skrárnar þínar voru dulritaðar með lykilorðinu '%s'.\n\nSkráðu þig inn í vefviðmótinu, farðu í hlutann 'Grunn-dulritunareining' (basic encryption module) í persónulegu stillingunum þínum og uppfærðu dulritunarlykilorðið þitt með því að setja þetta lykilorð inn í reitinn 'Gamla innskráningarlykilorðið' ásamt núverandi innskráningarlykilorði.\n\n",
    "The share will expire on %s." : "Gildistími deilingar rennur út %s.",
    "Cheers!" : "Til hamingju!",
    "Hey there,<br><br>the admin enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.<br><br>" : "Hæ,<br><br>kerfisstjórinn virkjaði dulritun á vefþjóni. Skrárnar þínar voru dulritaðar með lykilorðinu <strong>%s</strong>.<br><br>Skráðu þig inn í vefviðmótinu, farðu í hlutann 'Grunn-dulritunareining' (basic encryption module) í persónulegu stillingunum þínum og uppfærðu dulritunarlykilorðið þitt með því að setja þetta lykilorð inn í reitinn 'Gamla innskráningarlykilorðið' ásamt núverandi innskráningarlykilorði.<br><br>",
    "Default encryption module" : "Sjálfgefin dulritunareining",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "Dulritunarforritið er virkt en dulritunarlyklarnir þínir eru ekki tilbúnir til notkunar, skráðu þig út og svo aftur inn",
    "Encrypt the home storage" : "Dulrita heimamöppuna",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Ef þessi kostur er virkur verða allar skrár í aðalgeymslu dulritaðar, annars verða einungis skrár í ytri gagnageymslum dulritaðar",
    "Enable recovery key" : "Virkja endurheimtingarlykil",
    "Disable recovery key" : "Gera endurheimtingarlykil óvirkan",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "Endurheimtingarlykill er auka-dulritunarlykill sem er notaður til að dulrita skrár. Hann gefur möguleika á að endurheimta skrár ef notandi gleymir lykilorðinu sínu.",
    "Recovery key password" : "Endurheimtulykilorð",
    "Repeat recovery key password" : "Endurtaktu endurheimtulykilorðið",
    "Change recovery key password:" : "Breyta endurheimtulykilorði:",
    "Old recovery key password" : "Gamla endurheimtulykilorðið",
    "New recovery key password" : "Nýtt endurheimtulykilorð",
    "Repeat new recovery key password" : "Endurtaktu nýja endurheimtulykilorðið",
    "Change Password" : "Breyta lykilorði",
    "Basic encryption module" : "Grunn-dulritunareining",
    "Your private key password no longer matches your log-in password." : "Lykilorð einkalykilsins þíns samsvarar ekki lengur innskráningarlykilorðinu þínu.",
    "Set your old private key password to your current log-in password:" : "Settu eldra lykilorð einkalykilsins þíns á að vera það sama og núgildandi innskráningarlykilorðið þitt:",
    " If you don't remember your old password you can ask your administrator to recover your files." : " Ef þú manst ekki gamla lykilorðið þitt geturðu beðið kerfisstjórann þinn um að endurheimta skrárnar þínar.",
    "Old log-in password" : "Gamla innskráningarlykilorðið",
    "Current log-in password" : "Núgildandi innskráningarlykilorð",
    "Update Private Key Password" : "Uppfæra lykilorð einkalykils:",
    "Enable password recovery:" : "Virkja endurheimtingu lykilorðs:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Ef þessi kostur er virkur gerir það þér kleift að endurheimta aðgang að skránum þínum ef þú tapar lykilorðinu",
    "Enabled" : "Virkt",
    "Disabled" : "Óvirkt"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
